{% extends '!modindex.html' %}

{% block extrahead %}
    <script type="text/javascript">
      DOCUMENTATION_OPTIONS.COLLAPSE_MODINDEX = true;
    </script>

<link rel="stylesheet"
  href="{{ pathto('_static/ingeniweb.css', 1) }}"
    type="text/css" />

{% endblock %}

