{% extends '!search.html' %}

{% block extrahead %}
    <script type="text/javascript" src="{{ pathto('_static/searchtools.js', 1) }}"></script>
   <link rel="stylesheet"
    href="{{ pathto('_static/ingeniweb.css', 1) }}"
    type="text/css" />

{% endblock %}

